==> lib_api-1.9.5-sources.jar: PctLocalConfig.java <==
package com.cv.media.lib.api.pct;

import com.cv.media.lib.common_utils.obfuscation.KeepClassMember;

import java.util.HashMap;
import java.util.List;
import java.util.Set;

/**
 * Created by zhangyaoa on 2023/6/27.
 */
public class PctLocalConfig implements KeepClassMember {
    private String custom_app_pct_package_name;
    private String custom_app_pct_release_id;
    private String custom_app_pct_key;
    private String custom_app_pct_nav_url;
    private String custom_app_pct_hard_type;
    private String custom_app_pct_metric_action;

    private String custom_app_pct_log_config;
    private String[] custom_app_pct_navigators;
    private String[] custom_app_pct_metric_url;
    private Set<String> custom_app_pct_black_list;
    private HashMap<String, String> custom_app_pct_sid_servers;

    public String getCustom_app_pct_package_name() {
        return custom_app_pct_package_name;
    }

    public void setCustom_app_pct_package_name(String custom_app_pct_package_name) {
        this.custom_app_pct_package_name = custom_app_pct_package_name;
    }

    public String getCustom_app_pct_release_id() {
        return custom_app_pct_release_id;
    }

    public void setCustom_app_pct_release_id(String custom_app_pct_release_id) {
        this.custom_app_pct_release_id = custom_app_pct_release_id;
    }

    public String getCustom_app_pct_key() {
        return custom_app_pct_key;
    }

    public void setCustom_app_pct_key(String custom_app_pct_key) {
        this.custom_app_pct_key = custom_app_pct_key;
    }

    public String getCustom_app_pct_nav_url() {
        return custom_app_pct_nav_url;
    }

    public void setCustom_app_pct_nav_url(String custom_app_pct_nav_url) {
        this.custom_app_pct_nav_url = custom_app_pct_nav_url;
    }

    public String getCustom_app_pct_hard_type() {
        return custom_app_pct_hard_type;
    }

    public void setCustom_app_pct_hard_type(String custom_app_pct_hard_type) {
        this.custom_app_pct_hard_type = custom_app_pct_hard_type;
    }

    public String[] getCustom_app_pct_navigators() {
        return custom_app_pct_navigators;
    }

    public void setCustom_app_pct_navigators(String[] custom_app_pct_navigators) {
        this.custom_app_pct_navigators = custom_app_pct_navigators;
    }

    public String[] getCustom_app_pct_metric_url() {
        return custom_app_pct_metric_url;
    }

    public void setCustom_app_pct_metric_url(String[] custom_app_pct_metric_url) {
        this.custom_app_pct_metric_url = custom_app_pct_metric_url;
    }

    public HashMap<String, String> getCustom_app_pct_sid_servers() {
        return custom_app_pct_sid_servers;
    }

    public void setCustom_app_pct_sid_servers(HashMap<String, String> custom_app_pct_sid_servers) {
        this.custom_app_pct_sid_servers = custom_app_pct_sid_servers;
    }

    public String getCustom_app_pct_metric_action() {
        return custom_app_pct_metric_action;
    }

    public void setCustom_app_pct_metric_action(String custom_app_pct_metric_action) {
        this.custom_app_pct_metric_action = custom_app_pct_metric_action;
    }

    public Set<String> getCustom_app_pct_black_list() {
        return custom_app_pct_black_list;
    }

    public void setCustom_app_pct_black_list(Set<String> custom_app_pct_black_list) {
        this.custom_app_pct_black_list = custom_app_pct_black_list;
    }

    public String getCustom_app_pct_log_config() {
        return custom_app_pct_log_config;
    }

    public void setCustom_app_pct_log_config(String custom_app_pct_log_config) {
        this.custom_app_pct_log_config = custom_app_pct_log_config;
    }
}

==> lib_api-2.0.8-sources.jar: PctLocalConfig.java <==
package com.cv.media.lib.api.pct;

import com.cv.media.lib.common_utils.obfuscation.KeepClassMember;

import java.util.HashMap;
import java.util.Set;

/**
 * Created by zhangyaoa on 2023/6/27.
 */
public class PctLocalConfig implements KeepClassMember {
    private String custom_app_pct_package_name;
    private String custom_app_pct_release_id;
    private String custom_app_pct_key;
    private String custom_app_pct_nav_url;
    private String custom_app_pct_hard_type;
    private String custom_app_pct_metric_action;

    private String custom_app_pct_log_config;
    private String[] custom_app_pct_navigators;
    private String[] custom_app_pct_metric_url;
    private Set<String> custom_app_pct_black_list;
    private HashMap<String, String> custom_app_pct_sid_servers;

    public String getCustom_app_pct_package_name() {
        return custom_app_pct_package_name;
    }

    public void setCustom_app_pct_package_name(String custom_app_pct_package_name) {
        this.custom_app_pct_package_name = custom_app_pct_package_name;
    }

    public String getCustom_app_pct_release_id() {
        return custom_app_pct_release_id;
    }

    public void setCustom_app_pct_release_id(String custom_app_pct_release_id) {
        this.custom_app_pct_release_id = custom_app_pct_release_id;
    }

    public String getCustom_app_pct_key() {
        return custom_app_pct_key;
    }

    public void setCustom_app_pct_key(String custom_app_pct_key) {
        this.custom_app_pct_key = custom_app_pct_key;
    }

    public String getCustom_app_pct_nav_url() {
        return custom_app_pct_nav_url;
    }

    public void setCustom_app_pct_nav_url(String custom_app_pct_nav_url) {
        this.custom_app_pct_nav_url = custom_app_pct_nav_url;
    }

    public String getCustom_app_pct_hard_type() {
        return custom_app_pct_hard_type;
    }

    public void setCustom_app_pct_hard_type(String custom_app_pct_hard_type) {
        this.custom_app_pct_hard_type = custom_app_pct_hard_type;
    }

    public String[] getCustom_app_pct_navigators() {
        return custom_app_pct_navigators;
    }

    public void setCustom_app_pct_navigators(String[] custom_app_pct_navigators) {
        this.custom_app_pct_navigators = custom_app_pct_navigators;
    }

    public String[] getCustom_app_pct_metric_url() {
        return custom_app_pct_metric_url;
    }

    public void setCustom_app_pct_metric_url(String[] custom_app_pct_metric_url) {
        this.custom_app_pct_metric_url = custom_app_pct_metric_url;
    }

    public HashMap<String, String> getCustom_app_pct_sid_servers() {
        return custom_app_pct_sid_servers;
    }

    public void setCustom_app_pct_sid_servers(HashMap<String, String> custom_app_pct_sid_servers) {
        if (this.custom_app_pct_sid_servers != null && custom_app_pct_sid_servers != null && !custom_app_pct_sid_servers.isEmpty()) {
            this.custom_app_pct_sid_servers.putAll(custom_app_pct_sid_servers);
        } else {
            this.custom_app_pct_sid_servers = custom_app_pct_sid_servers;
        }
    }

    public String getCustom_app_pct_metric_action() {
        return custom_app_pct_metric_action;
    }

    public void setCustom_app_pct_metric_action(String custom_app_pct_metric_action) {
        this.custom_app_pct_metric_action = custom_app_pct_metric_action;
    }

    public Set<String> getCustom_app_pct_black_list() {
        return custom_app_pct_black_list;
    }

    public void setCustom_app_pct_black_list(Set<String> custom_app_pct_black_list) {
        this.custom_app_pct_black_list = custom_app_pct_black_list;
    }

    public String getCustom_app_pct_log_config() {
        return custom_app_pct_log_config;
    }

    public void setCustom_app_pct_log_config(String custom_app_pct_log_config) {
        this.custom_app_pct_log_config = custom_app_pct_log_config;
    }
}
